==> tencentcloud-sdk-java-3.0.41-sources.jar: com/tencentcloudapi/yunjing/v20180228/models/OpenPortStatistics.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.yunjing.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class OpenPortStatistics  extends AbstractModel{

    /**
    * 端口号
    */
    @SerializedName("Port")
    @Expose
    private Integer Port;

    /**
    * 主机数量
    */
    @SerializedName("MachineNum")
    @Expose
    private Integer MachineNum;

    /**
     * 获取端口号
     * @return Port 端口号
     */
    public Integer getPort() {
        return this.Port;
    }

    /**
     * 设置端口号
     * @param Port 端口号
     */
    public void setPort(Integer Port) {
        this.Port = Port;
    }

    /**
     * 获取主机数量
     * @return MachineNum 主机数量
     */
    public Integer getMachineNum() {
        return this.MachineNum;
    }

    /**
     * 设置主机数量
     * @param MachineNum 主机数量
     */
    public void setMachineNum(Integer MachineNum) {
        this.MachineNum = MachineNum;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Port", this.Port);
        this.setParamSimple(map, prefix + "MachineNum", this.MachineNum);

    }
}

==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/yunjing/v20180228/models/OpenPortStatistics.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.yunjing.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class OpenPortStatistics extends AbstractModel{

    /**
    * 端口号
    */
    @SerializedName("Port")
    @Expose
    private Long Port;

    /**
    * 主机数量
    */
    @SerializedName("MachineNum")
    @Expose
    private Long MachineNum;

    /**
     * Get 端口号 
     * @return Port 端口号
     */
    public Long getPort() {
        return this.Port;
    }

    /**
     * Set 端口号
     * @param Port 端口号
     */
    public void setPort(Long Port) {
        this.Port = Port;
    }

    /**
     * Get 主机数量 
     * @return MachineNum 主机数量
     */
    public Long getMachineNum() {
        return this.MachineNum;
    }

    /**
     * Set 主机数量
     * @param MachineNum 主机数量
     */
    public void setMachineNum(Long MachineNum) {
        this.MachineNum = MachineNum;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Port", this.Port);
        this.setParamSimple(map, prefix + "MachineNum", this.MachineNum);

    }
}
